diff avcodec.h @ 6979:4257fdcf664e libavcodec

Rename last_frame_offset to next_frame_offset. (it was and is the next not the last)
author michael
date Mon, 02 Jun 2008 03:10:00 +0000
parents de032bcdeff9
children 2dde03056bd6
line wrap: on
line diff
--- a/avcodec.h	Mon Jun 02 03:07:32 2008 +0000
+++ b/avcodec.h	Mon Jun 02 03:10:00 2008 +0000
@@ -2822,7 +2822,7 @@
     int64_t frame_offset; /* offset of the current frame */
     int64_t cur_offset; /* current offset
                            (incremented by each av_parser_parse()) */
-    int64_t last_frame_offset; /* offset of the last frame */
+    int64_t next_frame_offset; /* offset of the next frame */
     /* video info */
     int pict_type; /* XXX: Put it back in AVCodecContext. */
     int repeat_pict; /* XXX: Put it back in AVCodecContext. */